def lorem_indo():
	return "Lorem Ipsum adalah contoh teks atau dummy"\
	+ "dalam industri percetakan dan typesetting."
	
def lorem_english():
	return "Lorem Ipsum is simply dummy text of the "\
	+ "printing and typesetting industry." 
