from setuptools import setup


setup(name='package-pertama',
	  version='0.1',
	  description='Latihan membuat package di Python',
	  url='http://github.com/yanwarsolah/package-pertama',
	  author='Yanwar Solahudin',
	  author_email='yanwarsolah@gmail.com',
	  license='MIT',
	  packages=['package_pertama'],
	  zip_safe=False)
